import os

from rostran.core.settings import RULES_DIR

TF_RULES_DIR = os.path.join(RULES_DIR, "terraform")
TF_ALI_RULES_DIR = os.path.join(TF_RULES_DIR, "alicloud")
CF_RULES_DIR = os.path.join(RULES_DIR, "cloudformation")
CF_RESOURCE_RULES_DIR = os.path.join(CF_RULES_DIR, "resource")

TF_ALI_ROS_PROP_MAPPINGS = {
    "*": {
        "availability_zone": "ZoneId",
        "data_disks": "DiskMappings",
        "security_group": "SecurityGroupIds",
        "vswitch_id": "VSwitchId",
        "vswitch_name": "VSwitchName",
        "userdata": "UserData",
    },
    "alicloud_instance": {
        "key_name": "KeyPairName",
        "allocate_public_ip": "AllocatePublicIP",
        "data_disks.*.name": "DiskName",
    },
    "alicloud_actiontrail_trail": {
        "event_rw": "EventRW",
    },
    "alicloud_alidns_record": {"rr": "RR"},
    "alicloud_api_gateway_api": {
        "constant_parameters": "ConstParameters",
        "name": "ApiName",
        "request_parameters.*.in": "Location",
        "request_parameters.*.name": "ApiParameterName",
        "request_parameters.*.type": "ParameterType",
        "system_parameters.*.in": "Location",
        "system_parameters.*.name": "ParameterName",
        "system_parameters.*.name_service": "ServiceParameterName",
        "fc_service_config": "FunctionComputeConfig",
        "request_config": "RequestConfig",
    },
    "alicloud_api_gateway_app": {
        "name": "AppName",
    },
    "alicloud_slb_acl": {"entry_list": "AclEntries"},
}

TF_ALI_ROS_GENERATE_MAPPING = {
    "alicloud_actiontrail_trail": "ALIYUN::ACTIONTRAIL::Trail",
    "alicloud_adb_account": "ALIYUN::ADB::Account",
    "alicloud_adb_db_cluster": "ALIYUN::ADB::DBCluster",
    "alicloud_alb_acl": "ALIYUN::ALB::Acl",
    "alicloud_alb_health_check_template": "ALIYUN::ALB::HealthCheckTemplate",
    "alicloud_alb_listener": "ALIYUN::ALB::Listener",
    "alicloud_alb_listener_acl_attachment": "ALIYUN::ALB::AclAssociation",
    "alicloud_alb_listener_additional_certificate_attachment": "ALIYUN::ALB::AdditionalCertificateAssociation",
    "alicloud_alb_load_balancer": "ALIYUN::ALB::LoadBalancer",
    "alicloud_alb_rule": "ALIYUN::ALB::Rule",
    "alicloud_alb_security_policy": "ALIYUN::ALB::SecurityPolicy",
    "alicloud_alb_server_group": "ALIYUN::ALB::ServerGroup",
    "alicloud_alidns_domain": "ALIYUN::DNS::Domain",
    "alicloud_alidns_domain_group": "ALIYUN::DNS::DomainGroup",
    "alicloud_alidns_record": "ALIYUN::DNS::DomainRecord",
    "alicloud_alikafka_consumer_group": "ALIYUN::KAFKA::ConsumerGroup",
    "alicloud_alikafka_instance": "ALIYUN::KAFKA::Instance",
    "alicloud_alikafka_topic": "ALIYUN::KAFKA::Topic",
    "alicloud_amqp_binding": "ALIYUN::AMQP::Binding",
    "alicloud_amqp_exchange": "ALIYUN::AMQP::Exchange",
    "alicloud_amqp_instance": "ALIYUN::AMQP::Instance",
    "alicloud_amqp_queue": "ALIYUN::AMQP::Queue",
    "alicloud_amqp_virtual_host": "ALIYUN::AMQP::VirtualHost",
    "alicloud_api_gateway_api": "ALIYUN::ApiGateway::Api",
    "alicloud_api_gateway_app": "ALIYUN::ApiGateway::App",
    "alicloud_api_gateway_app_attachment": "ALIYUN::ApiGateway::Authorization",
    "alicloud_api_gateway_group": "ALIYUN::ApiGateway::Group",
    "alicloud_api_gateway_log_config": "ALIYUN::ApiGateway::LogConfig",
    "alicloud_api_gateway_plugin": "ALIYUN::ApiGateway::Plugin",
    "alicloud_arms_alert_contact": "ALIYUN::ARMS::AlertContact",
    "alicloud_arms_alert_contact_group": "ALIYUN::ARMS::AlertContactGroup",
    "alicloud_arms_prometheus": "ALIYUN::ARMS::ManagedPrometheus",
    "alicloud_auto_provisioning_group": "ALIYUN::ECS::AutoProvisioningGroup",
    "alicloud_cddc_dedicated_host": "ALIYUN::CDDC::DedicatedHost",
    "alicloud_cddc_dedicated_host_group": "ALIYUN::CDDC::DedicatedHostGroup",
    "alicloud_cdn_domain": "ALIYUN::CDN::Domain",
    "alicloud_cdn_domain_config": "ALIYUN::CDN::DomainConfig",
    "alicloud_cdn_domain_new": "ALIYUN::CDN::Domain",
    "alicloud_cen_bandwidth_limit": "ALIYUN::CEN::CenBandwidthLimit",
    "alicloud_cen_bandwidth_package": "ALIYUN::CEN::CenBandwidthPackage",
    "alicloud_cen_bandwidth_package_attachment": "ALIYUN::CEN::CenBandwidthPackageAssociation",
    "alicloud_cen_child_instance_route_entry_to_attachment": "ALIYUN::CEN::ChildInstanceRouteEntryToAttachment",
    "alicloud_cen_flowlog": "ALIYUN::VPC::FlowLog",
    "alicloud_cen_instance": "ALIYUN::CEN::CenInstance",
    "alicloud_cen_instance_attachment": "ALIYUN::CEN::CenInstanceAttachment",
    "alicloud_cen_route_entry": "ALIYUN::CEN::RouteEntry",
    "alicloud_cen_route_map": "ALIYUN::CEN::CenRouteMap",
    "alicloud_cen_route_service": "ALIYUN::CEN::CenRouteService",
    "alicloud_cen_transit_router": "ALIYUN::CEN::TransitRouter",
    "alicloud_cen_transit_router_peer_attachment": "ALIYUN::CEN::TransitRouterPeerAttachment",
    "alicloud_cen_transit_router_route_entry": "ALIYUN::CEN::TransitRouterRouteEntry",
    "alicloud_cen_transit_router_route_table": "ALIYUN::CEN::TransitRouterRouteTable",
    "alicloud_cen_transit_router_route_table_association": "ALIYUN::CEN::TransitRouterRouteTableAssociation",
    "alicloud_cen_transit_router_route_table_propagation": "ALIYUN::CEN::TransitRouterRouteTablePropagation",
    "alicloud_cen_transit_router_vbr_attachment": "ALIYUN::CEN::TransitRouterVbrAttachment",
    "alicloud_cen_transit_router_vpc_attachment": "ALIYUN::CEN::TransitRouterVpcAttachment",
    "alicloud_click_house_db_cluster": "ALIYUN::ClickHouse::DBCluster",
    "alicloud_cloud_connect_network": "ALIYUN::SAG::CloudConnectNetwork",
    "alicloud_cloud_connect_network_grant": "ALIYUN::SAG::GrantCcnToCen",
    "alicloud_cloud_firewall_vpc_firewall_control_policy": "ALIYUN::CLOUDFW::VpcFirewallControlPolicy",
    "alicloud_cms_alarm_contact": "ALIYUN::CMS::Contact",
    "alicloud_cms_alarm_contact_group": "ALIYUN::CMS::ContactGroup",
    "alicloud_cms_dynamic_tag_group": "ALIYUN::CMS::DynamicTagGroup",
    "alicloud_cms_event_rule": "ALIYUN::CMS::EventRule",
    "alicloud_cms_group_metric_rule": "ALIYUN::CMS::GroupMetricRule",
    "alicloud_cms_metric_rule_template": "ALIYUN::CMS::MetricRuleTemplate",
    "alicloud_cms_monitor_group": "ALIYUN::CMS::MonitorGroup",
    "alicloud_cms_monitor_group_instances": "ALIYUN::CMS::MonitorGroupInstances",
    "alicloud_cms_namespace": "ALIYUN::CMS::Namespace",
    "alicloud_cms_site_monitor": "ALIYUN::CMS::SiteMonitor",
    "alicloud_common_bandwidth_package": "ALIYUN::VPC::CommonBandwidthPackage",
    "alicloud_common_bandwidth_package_attachment": "ALIYUN::VPC::CommonBandwidthPackageIp",
    "alicloud_compute_nest_service_instance": "ALIYUN::ComputeNest::ServiceInstance",
    "alicloud_config_compliance_pack": "ALIYUN::Config::CompliancePack",
    "alicloud_config_delivery_channel": "ALIYUN::Config::DeliveryChannel",
    "alicloud_config_rule": "ALIYUN::Config::Rule",
    "alicloud_cr_ee_instance": "ALIYUN::CR::Instance",
    "alicloud_cr_ee_namespace": "ALIYUN::CR::Namespace",
    "alicloud_cr_ee_repo": "ALIYUN::CR::Repository",
    "alicloud_cr_endpoint_acl_policy": "ALIYUN::CR::InstanceEndpointAclPolicy",
    "alicloud_cr_namespace": "ALIYUN::CR::Namespace",
    "alicloud_cr_repo": "ALIYUN::CR::Repository",
    "alicloud_cr_vpc_endpoint_linked_vpc": "ALIYUN::CR::InstanceVpcEndpointLinkedVpc",
    "alicloud_cs_edge_kubernetes": "ALIYUN::CS::ManagedEdgeKubernetesCluster",
    "alicloud_cs_kubernetes": "ALIYUN::CS::KubernetesCluster",
    "alicloud_cs_kubernetes_addon": "ALIYUN::CS::ClusterAddons",
    "alicloud_cs_kubernetes_node_pool": "ALIYUN::CS::ClusterNodePool",
    "alicloud_cs_managed_kubernetes": "ALIYUN::CS::ManagedKubernetesCluster",
    "alicloud_cs_serverless_kubernetes": "ALIYUN::CS::ServerlessKubernetesCluster",
    "alicloud_datahub_project": "ALIYUN::DATAHUB::Project",
    "alicloud_datahub_topic": "ALIYUN::DATAHUB::Topic",
    "alicloud_db_account_privilege": "ALIYUN::RDS::AccountPrivilege",
    "alicloud_db_connection": "ALIYUN::RDS::Connection",
    "alicloud_db_database": "ALIYUN::RDS::Database",
    "alicloud_db_instance": "ALIYUN::RDS::DBInstance",
    "alicloud_db_readonly_instance": "ALIYUN::RDS::ReadOnlyDBInstance",
    "alicloud_dcdn_domain": "ALIYUN::DCDN::Domain",
    "alicloud_dfs_access_group": "ALIYUN::DFS::AccessGroup",
    "alicloud_dfs_access_rule": "ALIYUN::DFS::AccessRule",
    "alicloud_dfs_file_system": "ALIYUN::DFS::FileSystem",
    "alicloud_dfs_mount_point": "ALIYUN::DFS::MountPoint",
    "alicloud_direct_mail_domain": "ALIYUN::DirectMail::Domain",
    "alicloud_dms_enterprise_instance": "ALIYUN::DMS::Instance",
    "alicloud_dns_group": "ALIYUN::DNS::DomainGroup",
    "alicloud_dns_record": "ALIYUN::DNS::DomainRecord",
    "alicloud_drds_instance": "ALIYUN::DRDS::DrdsInstance",
    "alicloud_drds_polardbx_instance": "ALIYUN::PolarDBX::DBInstance",
    "alicloud_dts_migration_job": "ALIYUN::DTS::MigrationJob",
    "alicloud_dts_synchronization_job": "ALIYUN::DTS::SynchronizationJob",
    "alicloud_eais_instance": "ALIYUN::EAIS::Instance",
    "alicloud_ebs_disk_replica_group": "ALIYUN::EBS::DiskReplicaGroup",
    "alicloud_ebs_disk_replica_pair": "ALIYUN::EBS::DiskReplicaPair",
    "alicloud_ecd_bundle": "ALIYUN::ECD::Bundle",
    "alicloud_ecd_desktop": "ALIYUN::ECD::Desktops",
    "alicloud_ecd_simple_office_site": "ALIYUN::ECD::SimpleOfficeSite",
    "alicloud_eci_container_group": "ALIYUN::ECI::ContainerGroup",
    "alicloud_eci_image_cache": "ALIYUN::ECI::ImageCache",
    "alicloud_ecp_instance": "ALIYUN::CloudPhone::InstanceGroup",
    "alicloud_ecs_activation": "ALIYUN::ECS::Activation",
    "alicloud_ecs_auto_snapshot_policy": "ALIYUN::ECS::AutoSnapshotPolicy",
    "alicloud_ecs_command": "ALIYUN::ECS::Command",
    "alicloud_ecs_dedicated_host": "ALIYUN::ECS::DedicatedHost",
    "alicloud_ecs_deployment_set": "ALIYUN::ECS::DeploymentSet",
    "alicloud_ecs_disk": "ALIYUN::ECS::Disk",
    "alicloud_ecs_disk_attachment": "ALIYUN::ECS::DiskAttachment",
    "alicloud_ecs_hpc_cluster": "ALIYUN::ECS::HpcCluster",
    "alicloud_ecs_instance_set": "ALIYUN::ECS::InstanceGroup",
    "alicloud_ecs_invocation": "ALIYUN::ECS::Invocation",
    "alicloud_ecs_key_pair": "ALIYUN::ECS::SSHKeyPair",
    "alicloud_ecs_key_pair_attachment": "ALIYUN::ECS::SSHKeyPairAttachment",
    "alicloud_ecs_launch_template": "ALIYUN::ECS::LaunchTemplate",
    "alicloud_ecs_network_interface": "ALIYUN::ECS::NetworkInterface",
    "alicloud_ecs_network_interface_attachment": "ALIYUN::ECS::NetworkInterfaceAttachment",
    "alicloud_ecs_network_interface_permission": "ALIYUN::ECS::NetworkInterfacePermission",
    "alicloud_ecs_prefix_list": "ALIYUN::ECS::PrefixList",
    "alicloud_ecs_snapshot": "ALIYUN::ECS::Snapshot",
    "alicloud_edas_application": "ALIYUN::EDAS::Application",
    "alicloud_edas_cluster": "ALIYUN::EDAS::Cluster",
    "alicloud_edas_deploy_group": "ALIYUN::EDAS::DeployGroup",
    "alicloud_edas_k8s_application": "ALIYUN::EDAS::K8sApplication",
    "alicloud_edas_k8s_cluster": "ALIYUN::EDAS::K8sCluster",
    "alicloud_edas_k8s_slb_attachment": "ALIYUN::EDAS::K8sSlbBinding",
    "alicloud_edas_namespace": "ALIYUN::EDAS::UserDefineRegion",
    "alicloud_ehpc_cluster": "ALIYUN::EHPC::Cluster",
    "alicloud_eip_address": "ALIYUN::VPC::EIP",
    "alicloud_eip_association": "ALIYUN::VPC::EIPAssociation",
    "alicloud_eip_segment_address": "ALIYUN::VPC::EIPSegment",
    "alicloud_eipanycast_anycast_eip_address": "ALIYUN::VPC::AnycastEIP",
    "alicloud_eipanycast_anycast_eip_address_attachment": "ALIYUN::VPC::AnycastEIPAssociation",
    "alicloud_elasticsearch_instance": "ALIYUN::ElasticSearch::Instance",
    "alicloud_emr_cluster": "ALIYUN::EMR::Cluster",
    "alicloud_emrv2_cluster": "ALIYUN::EMR::Cluster2",
    "alicloud_ens_instance": "ALIYUN::ENS::Instance",
    "alicloud_ess_alarm": "ALIYUN::ESS::AlarmTask",
    "alicloud_ess_alb_server_group_attachment": "ALIYUN::ESS::ServerGroupAttachment",
    "alicloud_ess_lifecycle_hook": (
        "alicloud_ess_lifecyclehook",
        "ALIYUN::ESS::LifecycleHook",
    ),
    "alicloud_ess_scaling_configuration": "ALIYUN::ESS::ScalingConfiguration",
    "alicloud_ess_scaling_group": "ALIYUN::ESS::ScalingGroup",
    "alicloud_ess_scaling_rule": (
        "alicloud_ess_scalingrule",
        "ALIYUN::ESS::ScalingRule",
    ),
    "alicloud_ess_scheduled_task": "ALIYUN::ESS::ScheduledTask",
    "alicloud_event_bridge_rule": "ALIYUN::EventBridge::Rule",
    "alicloud_fc_alias": "ALIYUN::FC::Alias",
    "alicloud_fc_custom_domain": "ALIYUN::FC::CustomDomain",
    "alicloud_fc_function": "ALIYUN::FC::Function",
    "alicloud_fc_service": "ALIYUN::FC::Service",
    "alicloud_fc_trigger": "ALIYUN::FC::Trigger",
    "alicloud_fnf_flow": "ALIYUN::FNF::Flow",
    "alicloud_fnf_schedule": "ALIYUN::FNF::Schedule",
    "alicloud_forward_entry": "ALIYUN::ECS::ForwardEntry",
    "alicloud_ga_accelerator": "ALIYUN::GA::Accelerator",
    "alicloud_ga_bandwidth_package": "ALIYUN::GA::BandwidthPackage",
    "alicloud_ga_bandwidth_package_attachment": "ALIYUN::GA::BandwidthPackageAcceleratorAddition",
    "alicloud_ga_endpoint_group": "ALIYUN::GA::EndpointGroup",
    "alicloud_ga_ip_set": "ALIYUN::GA::IpSets",
    "alicloud_ga_listener": "ALIYUN::GA::Listener",
    "alicloud_gpdb_account": "ALIYUN::GPDB::Account",
    "alicloud_gpdb_elastic_instance": "ALIYUN::GPDB::ElasticDBInstance",
    "alicloud_gpdb_instance": "ALIYUN::GPDB::DBInstance",
    "alicloud_havip_attachment": "ALIYUN::VPC::HaVipAssociation",
    "alicloud_hbr_ecs_backup_client": "ALIYUN::HBR::BackupClients",
    "alicloud_hbr_restore_job": "ALIYUN::HBR::RestoreJob",
    "alicloud_hbr_vault": "ALIYUN::HBR::Vault",
    "alicloud_image": "ALIYUN::ECS::CustomImage",
    "alicloud_image_copy": "ALIYUN::ECS::CopyImage",
    "alicloud_imm_project": "ALIYUN::IMM::Project",
    "alicloud_instance": "ALIYUN::ECS::Instance",
    "alicloud_iot_device_group": "ALIYUN::IOT::DeviceGroup",
    "alicloud_kms_alias": "ALIYUN::KMS::Alias",
    "alicloud_kms_key": "ALIYUN::KMS::Key",
    "alicloud_kms_secret": "ALIYUN::KMS::Secret",
    "alicloud_kvstore_account": "ALIYUN::REDIS::Account",
    "alicloud_kvstore_connection": "ALIYUN::REDIS::Connection",
    "alicloud_kvstore_instance": "ALIYUN::REDIS::Instance",
    "alicloud_lindorm_instance": "ALIYUN::Lindorm::Instance",
    "alicloud_log_alert": "ALIYUN::SLS::Alert",
    "alicloud_log_audit": "ALIYUN::SLS::Audit",
    "alicloud_log_dashboard": "ALIYUN::SLS::Dashboard",
    "alicloud_log_etl": "ALIYUN::SLS::Etl",
    "alicloud_log_machine_group": "ALIYUN::SLS::MachineGroup",
    "alicloud_log_project": "ALIYUN::SLS::Project",
    "alicloud_log_store": "ALIYUN::SLS::Logstore",
    "alicloud_log_store_index": "ALIYUN::SLS::Index",
    "alicloud_logtail_config": "ALIYUN::SLS::LogtailConfig",
    "alicloud_market_order": "ALIYUN::MarketPlace::Order",
    "alicloud_message_service_queue": "ALIYUN::MNS::Queue",
    "alicloud_message_service_subscription": "ALIYUN::MNS::Subscription",
    "alicloud_message_service_topic": "ALIYUN::MNS::Topic",
    "alicloud_mns_queue": "ALIYUN::MNS::Queue",
    "alicloud_mns_topic": "ALIYUN::MNS::Topic",
    "alicloud_mns_topic_subscription": "ALIYUN::MNS::Subscription",
    "alicloud_mongodb_instance": "ALIYUN::MONGODB::Instance",
    "alicloud_mongodb_sharding_instance": "ALIYUN::MONGODB::ShardingInstance",
    "alicloud_mse_cluster": "ALIYUN::MSE::Cluster",
    "alicloud_mse_gateway": "ALIYUN::MSE::Gateway",
    "alicloud_nas_access_group": "ALIYUN::NAS::AccessGroup",
    "alicloud_nas_access_rule": "ALIYUN::NAS::AccessRule",
    "alicloud_nas_data_flow": "ALIYUN::NAS::DataFlow",
    "alicloud_nas_file_system": "ALIYUN::NAS::FileSystem",
    "alicloud_nas_fileset": "ALIYUN::NAS::Fileset",
    "alicloud_nas_mount_target": "ALIYUN::NAS::MountTarget",
    "alicloud_nat_gateway": "ALIYUN::VPC::NatGateway",
    "alicloud_network_acl": "ALIYUN::VPC::NetworkAcl",
    "alicloud_network_acl_attachment": "ALIYUN::VPC::NetworkAclAssociation",
    "alicloud_nlb_listener": "ALIYUN::NLB::Listener",
    "alicloud_nlb_load_balancer": "ALIYUN::NLB::LoadBalancer",
    "alicloud_nlb_server_group": "ALIYUN::NLB::ServerGroup",
    "alicloud_ons_group": "ALIYUN::ROCKETMQ::Group",
    "alicloud_ons_instance": "ALIYUN::ROCKETMQ::Instance",
    "alicloud_ons_topic": "ALIYUN::ROCKETMQ::Topic",
    "alicloud_oos_default_patch_baseline": "ALIYUN::OOS::DefaultPatchBaseline",
    "alicloud_oos_execution": "ALIYUN::OOS::Execution",
    "alicloud_oos_parameter": "ALIYUN::OOS::Parameter",
    "alicloud_oos_patch_baseline": "ALIYUN::OOS::PatchBaseline",
    "alicloud_oos_secret_parameter": "ALIYUN::OOS::SecretParameter",
    "alicloud_oos_template": "ALIYUN::OOS::Template",
    "alicloud_oss_bucket": "ALIYUN::OSS::Bucket",
    "alicloud_ots_instance": "ALIYUN::OTS::Instance",
    "alicloud_ots_search_index": "ALIYUN::OTS::SearchIndex",
    "alicloud_ots_table": "ALIYUN::OTS::Table",
    "alicloud_polardb_account": "ALIYUN::POLARDB::Account",
    "alicloud_polardb_account_privilege": "ALIYUN::POLARDB::AccountPrivilege",
    "alicloud_polardb_cluster": "ALIYUN::POLARDB::DBCluster",
    "alicloud_polardb_database": "ALIYUN::POLARDB::DBInstance",
    "alicloud_polardb_endpoint": "ALIYUN::POLARDB::DBClusterEndpoint",
    "alicloud_polardb_endpoint_address": "ALIYUN::POLARDB::DBClusterEndpointAddress",
    "alicloud_polardb_global_database_network": "ALIYUN::POLARDB::GlobalDatabaseNetwork",
    "alicloud_polardb_parameter_group": "ALIYUN::POLARDB::ParameterGroup",
    "alicloud_privatelink_vpc_endpoint": "ALIYUN::PrivateLink::VpcEndpoint",
    "alicloud_privatelink_vpc_endpoint_service": "ALIYUN::PrivateLink::VpcEndpointService",
    "alicloud_pvtz_rule": "ALIYUN::PVTZ::Rule",
    "alicloud_pvtz_user_vpc_authorization": "ALIYUN::PVTZ::UserVpcAuthorization",
    "alicloud_pvtz_zone": "ALIYUN::PVTZ::Zone",
    "alicloud_pvtz_zone_record": "ALIYUN::PVTZ::ZoneRecord",
    "alicloud_ram_access_key": "ALIYUN::RAM::AccessKey",
    "alicloud_ram_account_alias": "ALIYUN::RAM::RamAccountAlias",
    "alicloud_ram_group": "ALIYUN::RAM::Group",
    "alicloud_ram_policy": "ALIYUN::RAM::ManagedPolicy",
    "alicloud_ram_role": "ALIYUN::RAM::Role",
    "alicloud_ram_role_policy_attachment": "ALIYUN::RAM::AttachPolicyToRole",
    "alicloud_ram_saml_provider": "ALIYUN::RAM::SAMLProvider",
    "alicloud_ram_security_preference": "ALIYUN::RAM::SecurityPreference",
    "alicloud_ram_user": "ALIYUN::RAM::User",
    "alicloud_ram_user_policy_attachment": "ALIYUN::RAM::AttachPolicyToUser",
    "alicloud_rds_account": "ALIYUN::RDS::Account",
    "alicloud_redis_tair_instance": "ALIYUN::REDIS::Instance",
    "alicloud_resource_manager_account": "ALIYUN::ResourceManager::Account",
    "alicloud_resource_manager_control_policy": "ALIYUN::ResourceManager::ControlPolicy",
    "alicloud_resource_manager_control_policy_attachment": "ALIYUN::ResourceManager::ControlPolicyAttachment",
    "alicloud_resource_manager_folder": "ALIYUN::ResourceManager::Folder",
    "alicloud_resource_manager_handshake": "ALIYUN::ResourceManager::Handshake",
    "alicloud_resource_manager_policy_attachment": "ALIYUN::ResourceManager::PolicyAttachment",
    "alicloud_resource_manager_resource_directory": "ALIYUN::ResourceManager::ResourceDirectory",
    "alicloud_resource_manager_resource_group": "ALIYUN::ResourceManager::ResourceGroup",
    "alicloud_resource_manager_resource_share": "ALIYUN::ResourceManager::ResourceShare",
    "alicloud_ros_stack": "ALIYUN::ROS::Stack",
    "alicloud_ros_stack_group": "ALIYUN::ROS::StackGroup",
    "alicloud_ros_stack_instance": "ALIYUN::ROS::StackInstances",
    "alicloud_route_entry": "ALIYUN::ECS::Route",
    "alicloud_route_table": "ALIYUN::VPC::RouteTable",
    "alicloud_route_table_attachment": "ALIYUN::VPC::RouteTableAssociation",
    "alicloud_router_interface": "ALIYUN::VPC::RouterInterface",
    "alicloud_router_interface_connection": "ALIYUN::VPC::PeeringRouterInterfaceConnection",
    "alicloud_sae_application": "ALIYUN::SAE::Application",
    "alicloud_sae_namespace": "ALIYUN::SAE::Namespace",
    "alicloud_sag_acl": "ALIYUN::SAG::ACL",
    "alicloud_sag_acl_rule": "ALIYUN::SAG::ACLRule",
    "alicloud_sag_qos": "ALIYUN::SAG::Qos",
    "alicloud_sag_qos_car": "ALIYUN::SAG::QosCar",
    "alicloud_sag_qos_policy": "ALIYUN::SAG::QosPolicy",
    "alicloud_security_group": "ALIYUN::ECS::SecurityGroup",
    "alicloud_security_group_rule": "ALIYUN::ECS::SecurityGroupIngress",
    "alicloud_simple_application_server_instance": "ALIYUN::SWAS::Instance",
    "alicloud_slb_acl": "ALIYUN::SLB::AccessControl",
    "alicloud_slb_attachment": "ALIYUN::SLB::BackendServerAttachment",
    "alicloud_slb_backend_server": "ALIYUN::SLB::BackendServerAttachment",
    "alicloud_slb_ca_certificate": "ALIYUN::SLB::Certificate",
    "alicloud_slb_domain_extension": "ALIYUN::SLB::DomainExtension",
    "alicloud_slb_listener": "ALIYUN::SLB::Listener",
    "alicloud_slb_load_balancer": "ALIYUN::SLB::LoadBalancer",
    "alicloud_slb_master_slave_server_group": "ALIYUN::SLB::MasterSlaveServerGroup",
    "alicloud_slb_rule": "ALIYUN::SLB::Rule",
    "alicloud_slb_server_certificate": "ALIYUN::SLB::Certificate",
    "alicloud_slb_server_group": "ALIYUN::SLB::VServerGroup",
    "alicloud_slb_server_group_server_attachment": "ALIYUN::SLB::BackendServerToVServerGroupAddition",
    "alicloud_snat_entry": "ALIYUN::ECS::SNatEntry",
    "alicloud_ssl_certificates_service_certificate": "ALIYUN::CAS::Certificate",
    "alicloud_ssl_vpn_client_cert": "ALIYUN::VPC::SslVpnClientCert",
    "alicloud_ssl_vpn_server": "ALIYUN::VPC::SslVpnServer",
    "alicloud_threat_detection_anti_brute_force_rule": "ALIYUN::ThreatDetection::AntiBruteForceRule",
    "alicloud_tsdb_instance": "ALIYUN::TSDB::HiTSDBInstance",
    "alicloud_vod_editing_project": "ALIYUN::VOD::EditingProject",
    "alicloud_vpc": "ALIYUN::ECS::VPC",
    "alicloud_vpc_bgp_group": "ALIYUN::VPC::BgpGroup",
    "alicloud_vpc_bgp_network": "ALIYUN::VPC::BgpNetwork",
    "alicloud_vpc_bgp_peer": "ALIYUN::VPC::BgpPeer",
    "alicloud_vpc_dhcp_options_set": "ALIYUN::VPC::DhcpOptionsSet",
    "alicloud_vpc_dhcp_options_set_attachment": "ALIYUN::VPC::DhcpOptionsSetAttachment",
    "alicloud_vpc_flow_log": "ALIYUN::VPC::FlowLog",
    "alicloud_vpc_ha_vip": "ALIYUN::VPC::HaVip",
    "alicloud_vpc_ipv4_gateway": "ALIYUN::VPC::Ipv4Gateway",
    "alicloud_vpc_ipv6_gateway": "ALIYUN::VPC::Ipv6Gateway",
    "alicloud_vpc_ipv6_internet_bandwidth": "ALIYUN::VPC::Ipv6InternetBandwidth",
    "alicloud_vpc_nat_ip": "ALIYUN::VPC::NatIp",
    "alicloud_vpc_network_acl_attachment": "ALIYUN::VPC::NetworkAclAssociation",
    "alicloud_vpc_peer_connection": "ALIYUN::VPC::VpcPeerConnection",
    "alicloud_vpc_prefix_list": "ALIYUN::VPC::PrefixList",
    "alicloud_vpc_traffic_mirror_filter": "ALIYUN::VPC::TrafficMirrorFilter",
    "alicloud_vpc_traffic_mirror_session": "ALIYUN::VPC::TrafficMirrorSession",
    "alicloud_vpn_connection": "ALIYUN::VPC::VpnConnection",
    "alicloud_vpn_customer_gateway": "ALIYUN::VPC::CustomerGateway",
    "alicloud_vpn_gateway": "ALIYUN::VPC::VpnGateway",
    "alicloud_vpn_ipsec_server": "ALIYUN::VPC::IpsecServer",
    "alicloud_vpn_pbr_route_entry": "ALIYUN::VPC::VpnPbrRouteEntry",
    "alicloud_vpn_route_entry": "ALIYUN::VPC::VpnRouteEntry",
    "alicloud_vswitch": "ALIYUN::ECS::VSwitch",
    "alicloud_waf_domain": "ALIYUN::WAF::Domain",
    "alicloud_waf_instance": "ALIYUN::WAF::Instance",
}
